The ‘What’ and ‘Why’ of a Risk Assessment
=========================================

Running a business means running risks
--------------------------------------

An entrepreneur is exposed to risks; you know this better than anyone. The
product in which you have invested needs to succeed. What if your customers do
not pay, or if there is a burglary at your premises? These are all risks. This
is all part of being an entrepreneur. As long as all is well, you and your
employees will be able to earn a decent living.

Are you aware of all the risks? Including the risks to your employees and your equipment? 
-----------------------------------------------------------------------------------------

What if there is an accident with one of the machines? What if an employee is
exposed to hazardous substances? What if somebody is unable to work because the
work is too demanding, or too much? This will cause production to halt, or you
will have to cope with one less person. Then there are still the costs for
repairs and healthcare. Not to mention the danger to your reputation. These are
substantial risks.

An RA will allow you to define these risks. This enables you to tackle them head on! 
-------------------------------------------------------------------------------------

You have probably heard of a Risk Assessment, or RA, before. An RA consists of
two parts: a LIST with all the risks to your company and a PLAN to deal with
them. These two components allow you to limit the risks to your employees and
your company, and therefore also the financial risk.

The RA is not complicated. It is compulsory for almost every entrepreneur with employees! 
------------------------------------------------------------------------------------------

Complicated? Not really. It just takes a bit of time. However, the RA is
important. So important that the government has made it compulsory for almost
all entrepreneurs with employees.

An RA is a legal requirement
----------------------------

Every company must conduct an RA and draw up a Plan of Action. A company is
responsible for the health and safety of its employees. That is logical. As an
employer, you want to live up to this responsibility. To do so, you need to
know what the health and safety risks are for your company. These risks can be
determined using this RA. They can be determined in such a way that you know
where to improve the working conditions and what risks to eliminate.

How often should an RA be performed?
------------------------------------

Conduct an RA regularly. Especially if there are any changes in your company.
For example, when you buy a new machine, after reconstruction or after moving.
A rule of thumb is once every four to five years. You do not have to start the
RA from scratch every time.

How should an RA be conducted?
------------------------------

You can conduct the RA yourself. You can also ask your employees to complete
some of the questions. This is a good opportunity to ask them whether they have
seen points for improvement, which is motivational! Also involve the employee
representative body. 

Reducing risks in four steps
----------------------------

These four steps are the best way of reducing the risks:

1. Identification.  All the hazards in your company on one list 
2. Evaluation. Determine the level of each risk 
3. Action Plan . Indicate how to solve the risk and plan who does what and when? 
4. Report and Keep it up-to-date. Done? Then you are on your way! 

Step 1: Identification
~~~~~~~~~~~~~~~~~~~~~~

All the hazards on one list: draw up a list of all the hazards in your company.
You can draw this list up yourself. (Or you can ask an expert to conduct your
RA.) 

Your RA must answer the following six questions:

* Have there been accidents in the past in my company? 
* What could currently go wrong in my company, causing accidents or absenteeism? 
* How great is the chance of this happening? 
* How do I limit a risk? Or limit the damage if something does go wrong? 
* What precautions are necessary? And how do I implement these? 
* How do I ensure that the precautions continue to work?

Step 2: Evaluation
~~~~~~~~~~~~~~~~~~

The result is a summary of the bottlenecks in your company. For each bottleneck
you will evaluate the magnitude of the hazards: you define the risks.

Step 3: Action Plan 
~~~~~~~~~~~~~~~~~~~

You indicate how you will solve the bottlenecks. Compare all the risks on the
list and place them in the correct order. Which risks are the most threatening?
Are there situations in your company that are not legally permissible? Which
risks could cause damage to your employees, equipment or the production
process? Which risks would your employees like you to tackle? Which
modifications are technically feasible and – also important – how much can you
invest? 

Next step: compare who does what and when?  You now have a list of ‘Things to
Do’. The third step is: set time periods for tackling the risks in your
company. Who will start working on which risk? And when will you be satisfied?
What will it provide? In short, a plan of action.  This allows you to resolve
the risks one at a time, preferably at the source. Perhaps you can solve
several problems at once.

Step 4: Report - Keep it up-to-date 
~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

Done? Then you are on your way!  That sounds odd. Once you are done that means
you are finished, right? This does not apply to the RA. You will implement the
Plan.  You will discuss the progress with your employees every year. If you
make changes in the company, you must change the RA too. New machines, new
working method, reorganisation? Changes in your company mean a modified RA. So,
if you have finished your (first) RA, you have only just started. You have
started to improve the health and safety standards in your company. And
improvements are never finished!
